""" Lotka volterra DDE """

from pylab import *
from ddeint import ddeint


def model(Y,t,d):
    x,y = Y(t)
    xd,yd = Y(t-d)
    return array([0.5*x*(1-yd), -0.5*y*(1-xd)])

g = lambda t : array([1,2])
tt = linspace(2,30,20000)

fig, ax = subplots(1,figsize=(4,4))

for d in [0, 0.2]:
    print( "Computing for d=%.02f"%d )
    yy = ddeint(model,g,tt,fargs=(d,))
    # WE PLOT X AGAINST Y
    ax.plot(yy[:,0], yy[:,1], lw=2, label='delay = %.01f'%d)
    
show()


""" Reproduces the sine function using a DDE """

from pylab import *
from ddeint import ddeint

model = lambda Y,t : Y(t - 3*pi/2) # Model
tt = linspace(0,50,10000) # Time start, time end, nb of pts/steps
g=sin # Expression of Y(t) before the integration interval
yy = ddeint(model,g,tt) # Solving

fig, ax = subplots(1,figsize=(4,4))
ax.plot(tt,yy)
show()


""" DDE with multiple variables """

from pylab import *
from ddeint import ddeint

model = lambda Y,t:  -Y( t-3*cos( Y(t) )**2 )
tt = linspace(0, 30, 2000)
yy = ddeint(model, lambda t:1, tt)

fig, ax = subplots(1,figsize=(4,4))
ax.plot(tt, yy)
    
show()


import ez_setup
ez_setup.use_setuptools()

from setuptools import setup, find_packages

exec(open('ddeint/version.py').read()) # loads __version__

setup(name='ddeint',
      version=__version__,
      author='Zulko',
    description='Scipy-based Delay Differential Equations solver',
    long_description=open('README.rst').read(),
    license='see LICENSE.txt',
    keywords="delay differential equation DDE",
    packages= find_packages(exclude='docs'))
